package javax.swing.plaf.synth;

import java.util.Iterator;
import java.awt.Graphics;
import java.util.LinkedList;
import java.util.List;
import sun.swing.plaf.synth.DefaultSynthStyle;

class ParsedSynthStyle extends DefaultSynthStyle
{
    private static SynthPainter DELEGATING_PAINTER_INSTANCE;
    private ParsedSynthStyle.PainterInfo[] _painters;
    
    private static ParsedSynthStyle.PainterInfo[] mergePainterInfo(ParsedSynthStyle.PainterInfo[] array, ParsedSynthStyle.PainterInfo[] array2) {
        if (array == null) {
            return array2;
        }
        if (array2 == null) {
            return array;
        }
        int length = array.length;
        int length2 = array2.length;
        int n = 0;
        ParsedSynthStyle.PainterInfo[] array3 = new ParsedSynthStyle.PainterInfo[length + length2];
        System.arraycopy(array, 0, array3, 0, length);
        for (int i = 0; i < length2; ++i) {
            boolean n2 = false;
            int j = 0;
            while (j < length - n) {
                if (array2[i].equalsPainter(array[j])) {
                    array3[j] = array2[i];
                    ++n;
                    n2 = true;
                    break;
                }
                ++j;
            }
            if (n2 == 0) {
                array3[length + i - n] = array2[i];
            }
        }
        if (n > 0) {
            array3 = new ParsedSynthStyle.PainterInfo[array3.length - n];
            System.arraycopy(array3, 0, array3, 0, array3.length);
            return array3;
        }
        return array3;
    }
    
    public ParsedSynthStyle() {
    }
    
    public ParsedSynthStyle(DefaultSynthStyle style) {
        super(style);
        if ((style instanceof ParsedSynthStyle)) {
            ParsedSynthStyle parsedSynthStyle = (ParsedSynthStyle)style;
            if (parsedSynthStyle._painters != null) {
                this._painters = parsedSynthStyle._painters;
            }
        }
    }
    
    @Override
    public SynthPainter getPainter(SynthContext synthContext) {
        return ParsedSynthStyle.DELEGATING_PAINTER_INSTANCE;
    }
    
    public void setPainters(ParsedSynthStyle.PainterInfo[] painters) {
        this._painters = painters;
    }
    
    @Override
    public DefaultSynthStyle addTo(DefaultSynthStyle style) {
        if (!(style instanceof ParsedSynthStyle)) {
            style = new ParsedSynthStyle(style);
        }
        ParsedSynthStyle parsedSynthStyle = (ParsedSynthStyle)super.addTo(style);
        parsedSynthStyle._painters = mergePainterInfo(parsedSynthStyle._painters, this._painters);
        return parsedSynthStyle;
    }
    
    private SynthPainter getBestPainter(SynthContext synthContext, String s, int n) {
        ParsedSynthStyle.StateInfo stateInfo = (ParsedSynthStyle.StateInfo)this.getStateInfo(synthContext.getComponentState());
        SynthPainter bestPainter;
        if (stateInfo != null && (bestPainter = this.getBestPainter(stateInfo.getPainters(), s, n)) != null) {
            return bestPainter;
        }
        SynthPainter bestPainter2;
        if ((bestPainter2 = this.getBestPainter(this._painters, s, n)) != null) {
            return bestPainter2;
        }
        return SynthPainter.NULL_PAINTER;
    }
    
    private SynthPainter getBestPainter(ParsedSynthStyle.PainterInfo[] array, String s, int n) {
        if (array != null) {
            SynthPainter painter = null;
            SynthPainter painter2 = null;
            for (int i = array.length - 1; i >= 0; --i) {
                ParsedSynthStyle.PainterInfo painterInfo = array[i];
                if (painterInfo.getMethod() == s) {
                    if (painterInfo.getDirection() == n) {
                        return painterInfo.getPainter();
                    }
                    if (painter2 == null && painterInfo.getDirection() == -1) {
                        painter2 = painterInfo.getPainter();
                    }
                }
                else if (painter == null && painterInfo.getMethod() == null) {
                    painter = painterInfo.getPainter();
                }
            }
            if (painter2 != null) {
                return painter2;
            }
            return painter;
        }
        else {
            return null;
        }
    }
    
    @Override
    public String toString() {
        StringBuffer sb = new StringBuffer(super.toString());
        if (this._painters != null) {
            sb.append(",painters=[");
            for (int i = 0; i < this._painters.length; ++i) {
                sb.append(this._painters[i].toString());
            }
            sb.append("]");
        }
        return sb.toString();
    }
    
    static ParsedSynthStyle.PainterInfo[] access$100(ParsedSynthStyle.PainterInfo[] array, ParsedSynthStyle.PainterInfo[] array2) {
        return mergePainterInfo(array, array2);
    }
    
    static SynthPainter access$200(ParsedSynthStyle parsedSynthStyle, SynthContext synthContext, String s, int n) {
        return parsedSynthStyle.getBestPainter(synthContext, s, n);
    }
    
    static {
        ParsedSynthStyle.DELEGATING_PAINTER_INSTANCE = new ParsedSynthStyle.DelegatingPainter();
    }
    
    static class StateInfo extends DefaultSynthStyle.StateInfo
    {
        private ParsedSynthStyle.PainterInfo[] _painterInfo;
        
        public StateInfo() {
        }
        
        public StateInfo(DefaultSynthStyle.StateInfo info) {
            super(info);
            if ((info instanceof ParsedSynthStyle.StateInfo)) {
                this._painterInfo = ((ParsedSynthStyle.StateInfo)info)._painterInfo;
            }
        }
        
        public void setPainters(ParsedSynthStyle.PainterInfo[] painterInfo) {
            this._painterInfo = painterInfo;
        }
        
        public ParsedSynthStyle.PainterInfo[] getPainters() {
            return this._painterInfo;
        }
        
        @Override
        public Object clone() {
            return new ParsedSynthStyle.StateInfo(this);
        }
        
        @Override
        public DefaultSynthStyle.StateInfo addTo(DefaultSynthStyle.StateInfo addTo) {
            if (!(addTo instanceof ParsedSynthStyle.StateInfo)) {
                addTo = new StateInfo(addTo);
                return addTo;
            }
            addTo = super.addTo(addTo);
            ParsedSynthStyle.StateInfo stateInfo = (ParsedSynthStyle.StateInfo)addTo;
            stateInfo._painterInfo = ParsedSynthStyle.access$100(stateInfo._painterInfo, this._painterInfo);
            return addTo;
        }
        
        @Override
        public String toString() {
            StringBuffer sb = new StringBuffer(super.toString());
            sb.append(",painters=[");
            if (this._painterInfo != null) {
                for (int i = 0; i < this._painterInfo.length; ++i) {
                    sb.append("    ").append(this._painterInfo[i].toString());
                }
            }
            sb.append("]");
            return sb.toString();
        }
    }
    
    static class PainterInfo
    {
        private String _method;
        private SynthPainter _painter;
        private int _direction;
        
        PainterInfo(String s, SynthPainter painter, int direction) {
            if (s != null) {
                this._method = s.intern();
            }
            this._painter = painter;
            this._direction = direction;
        }
        
        void addPainter(SynthPainter synthPainter) {
            if (!(this._painter instanceof ParsedSynthStyle.AggregatePainter)) {
                this._painter = new ParsedSynthStyle.AggregatePainter(this._painter);
            }
            ((ParsedSynthStyle.AggregatePainter)this._painter).addPainter(synthPainter);
        }
        
        String getMethod() {
            return this._method;
        }
        
        SynthPainter getPainter() {
            return this._painter;
        }
        
        int getDirection() {
            return this._direction;
        }
        
        boolean equalsPainter(ParsedSynthStyle.PainterInfo painterInfo) {
            return this._method == painterInfo._method && this._direction == painterInfo._direction;
        }
        
        @Override
        public String toString() {
            return "PainterInfo {method=" + this._method + ",direction=" + this._direction + ",painter=" + this._painter + "}";
        }
    }
    
    private static class AggregatePainter extends SynthPainter
    {
        private List<SynthPainter> painters;
        
        AggregatePainter(SynthPainter synthPainter) {
            (this.painters = new LinkedList()).add(synthPainter);
        }
        
        void addPainter(SynthPainter synthPainter) {
            if (synthPainter != null) {
                this.painters.add(synthPainter);
            }
        }
        
        @Override
        public void paintArrowButtonBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintArrowButtonBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintArrowButtonBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintArrowButtonBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintArrowButtonForeground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintArrowButtonForeground(synthContext, graphics, n, n2, n3, n4, n5);
            }
        }
        
        @Override
        public void paintButtonBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintButtonBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintButtonBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintButtonBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintCheckBoxMenuItemBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintCheckBoxMenuItemBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintCheckBoxMenuItemBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintCheckBoxMenuItemBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintCheckBoxBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintCheckBoxBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintCheckBoxBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintCheckBoxBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintColorChooserBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintColorChooserBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintColorChooserBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintColorChooserBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintComboBoxBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintComboBoxBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintComboBoxBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintComboBoxBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintDesktopIconBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintDesktopIconBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintDesktopIconBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintDesktopIconBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintDesktopPaneBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintDesktopPaneBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintDesktopPaneBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintDesktopPaneBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintEditorPaneBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintEditorPaneBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintEditorPaneBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintEditorPaneBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintFileChooserBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintFileChooserBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintFileChooserBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintFileChooserBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintFormattedTextFieldBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintFormattedTextFieldBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintFormattedTextFieldBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintFormattedTextFieldBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintInternalFrameTitlePaneBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintInternalFrameTitlePaneBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintInternalFrameTitlePaneBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintInternalFrameTitlePaneBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintInternalFrameBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintInternalFrameBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintInternalFrameBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintInternalFrameBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintLabelBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintLabelBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintLabelBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintLabelBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintListBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintListBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintListBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintListBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintMenuBarBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintMenuBarBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintMenuBarBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintMenuBarBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintMenuItemBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintMenuItemBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintMenuItemBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintMenuItemBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintMenuBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintMenuBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintMenuBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintMenuBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintOptionPaneBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintOptionPaneBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintOptionPaneBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintOptionPaneBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintPanelBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintPanelBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintPanelBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintPanelBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintPasswordFieldBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintPasswordFieldBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintPasswordFieldBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintPasswordFieldBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintPopupMenuBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintPopupMenuBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintPopupMenuBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintPopupMenuBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintProgressBarBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintProgressBarBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintProgressBarBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintProgressBarBackground(synthContext, graphics, n, n2, n3, n4, n5);
            }
        }
        
        @Override
        public void paintProgressBarBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintProgressBarBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintProgressBarBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintProgressBarBorder(synthContext, graphics, n, n2, n3, n4, n5);
            }
        }
        
        @Override
        public void paintProgressBarForeground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintProgressBarForeground(synthContext, graphics, n, n2, n3, n4, n5);
            }
        }
        
        @Override
        public void paintRadioButtonMenuItemBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintRadioButtonMenuItemBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintRadioButtonMenuItemBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintRadioButtonMenuItemBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintRadioButtonBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintRadioButtonBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintRadioButtonBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintRadioButtonBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintRootPaneBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintRootPaneBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintRootPaneBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintRootPaneBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintScrollBarBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintScrollBarBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintScrollBarBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintScrollBarBackground(synthContext, graphics, n, n2, n3, n4, n5);
            }
        }
        
        @Override
        public void paintScrollBarBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintScrollBarBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintScrollBarBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintScrollBarBorder(synthContext, graphics, n, n2, n3, n4, n5);
            }
        }
        
        @Override
        public void paintScrollBarThumbBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintScrollBarThumbBackground(synthContext, graphics, n, n2, n3, n4, n5);
            }
        }
        
        @Override
        public void paintScrollBarThumbBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintScrollBarThumbBorder(synthContext, graphics, n, n2, n3, n4, n5);
            }
        }
        
        @Override
        public void paintScrollBarTrackBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintScrollBarTrackBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintScrollBarTrackBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintScrollBarTrackBackground(synthContext, graphics, n, n2, n3, n4, n5);
            }
        }
        
        @Override
        public void paintScrollBarTrackBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintScrollBarTrackBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintScrollBarTrackBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintScrollBarTrackBorder(synthContext, graphics, n, n2, n3, n4, n5);
            }
        }
        
        @Override
        public void paintScrollPaneBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintScrollPaneBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintScrollPaneBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintScrollPaneBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintSeparatorBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintSeparatorBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintSeparatorBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintSeparatorBackground(synthContext, graphics, n, n2, n3, n4, n5);
            }
        }
        
        @Override
        public void paintSeparatorBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintSeparatorBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintSeparatorBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintSeparatorBorder(synthContext, graphics, n, n2, n3, n4, n5);
            }
        }
        
        @Override
        public void paintSeparatorForeground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintSeparatorForeground(synthContext, graphics, n, n2, n3, n4, n5);
            }
        }
        
        @Override
        public void paintSliderBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintSliderBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintSliderBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintSliderBackground(synthContext, graphics, n, n2, n3, n4, n5);
            }
        }
        
        @Override
        public void paintSliderBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintSliderBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintSliderBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintSliderBorder(synthContext, graphics, n, n2, n3, n4, n5);
            }
        }
        
        @Override
        public void paintSliderThumbBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintSliderThumbBackground(synthContext, graphics, n, n2, n3, n4, n5);
            }
        }
        
        @Override
        public void paintSliderThumbBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintSliderThumbBorder(synthContext, graphics, n, n2, n3, n4, n5);
            }
        }
        
        @Override
        public void paintSliderTrackBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintSliderTrackBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintSliderTrackBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintSliderTrackBackground(synthContext, graphics, n, n2, n3, n4, n5);
            }
        }
        
        @Override
        public void paintSliderTrackBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintSliderTrackBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintSliderTrackBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintSliderTrackBorder(synthContext, graphics, n, n2, n3, n4, n5);
            }
        }
        
        @Override
        public void paintSpinnerBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintSpinnerBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintSpinnerBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintSpinnerBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintSplitPaneDividerBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintSplitPaneDividerBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintSplitPaneDividerBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintSplitPaneDividerBackground(synthContext, graphics, n, n2, n3, n4, n5);
            }
        }
        
        @Override
        public void paintSplitPaneDividerForeground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintSplitPaneDividerForeground(synthContext, graphics, n, n2, n3, n4, n5);
            }
        }
        
        @Override
        public void paintSplitPaneDragDivider(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintSplitPaneDragDivider(synthContext, graphics, n, n2, n3, n4, n5);
            }
        }
        
        @Override
        public void paintSplitPaneBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintSplitPaneBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintSplitPaneBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintSplitPaneBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintTabbedPaneBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintTabbedPaneBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintTabbedPaneBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintTabbedPaneBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintTabbedPaneTabAreaBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintTabbedPaneTabAreaBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintTabbedPaneTabAreaBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintTabbedPaneTabAreaBackground(synthContext, graphics, n, n2, n3, n4, n5);
            }
        }
        
        @Override
        public void paintTabbedPaneTabAreaBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintTabbedPaneTabAreaBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintTabbedPaneTabAreaBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintTabbedPaneTabAreaBorder(synthContext, graphics, n, n2, n3, n4, n5);
            }
        }
        
        @Override
        public void paintTabbedPaneTabBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintTabbedPaneTabBackground(synthContext, graphics, n, n2, n3, n4, n5);
            }
        }
        
        @Override
        public void paintTabbedPaneTabBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5, int n6) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintTabbedPaneTabBackground(synthContext, graphics, n, n2, n3, n4, n5, n6);
            }
        }
        
        @Override
        public void paintTabbedPaneTabBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintTabbedPaneTabBorder(synthContext, graphics, n, n2, n3, n4, n5);
            }
        }
        
        @Override
        public void paintTabbedPaneTabBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5, int n6) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintTabbedPaneTabBorder(synthContext, graphics, n, n2, n3, n4, n5, n6);
            }
        }
        
        @Override
        public void paintTabbedPaneContentBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintTabbedPaneContentBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintTabbedPaneContentBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintTabbedPaneContentBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintTableHeaderBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintTableHeaderBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintTableHeaderBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintTableHeaderBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintTableBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintTableBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintTableBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintTableBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintTextAreaBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintTextAreaBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintTextAreaBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintTextAreaBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintTextPaneBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintTextPaneBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintTextPaneBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintTextPaneBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintTextFieldBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintTextFieldBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintTextFieldBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintTextFieldBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintToggleButtonBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintToggleButtonBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintToggleButtonBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintToggleButtonBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintToolBarBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintToolBarBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintToolBarBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintToolBarBackground(synthContext, graphics, n, n2, n3, n4, n5);
            }
        }
        
        @Override
        public void paintToolBarBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintToolBarBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintToolBarBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintToolBarBorder(synthContext, graphics, n, n2, n3, n4, n5);
            }
        }
        
        @Override
        public void paintToolBarContentBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintToolBarContentBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintToolBarContentBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintToolBarContentBackground(synthContext, graphics, n, n2, n3, n4, n5);
            }
        }
        
        @Override
        public void paintToolBarContentBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintToolBarContentBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintToolBarContentBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintToolBarContentBorder(synthContext, graphics, n, n2, n3, n4, n5);
            }
        }
        
        @Override
        public void paintToolBarDragWindowBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintToolBarDragWindowBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintToolBarDragWindowBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintToolBarDragWindowBackground(synthContext, graphics, n, n2, n3, n4, n5);
            }
        }
        
        @Override
        public void paintToolBarDragWindowBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintToolBarDragWindowBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintToolBarDragWindowBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintToolBarDragWindowBorder(synthContext, graphics, n, n2, n3, n4, n5);
            }
        }
        
        @Override
        public void paintToolTipBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintToolTipBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintToolTipBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintToolTipBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintTreeBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintTreeBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintTreeBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintTreeBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintTreeCellBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintTreeCellBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintTreeCellBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintTreeCellBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintTreeCellFocus(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintTreeCellFocus(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintViewportBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintViewportBackground(synthContext, graphics, n, n2, n3, n4);
            }
        }
        
        @Override
        public void paintViewportBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            Iterator<SynthPainter> iterator = this.painters.iterator();
            while (iterator.hasNext()) {
                ((SynthPainter)iterator.next()).paintViewportBorder(synthContext, graphics, n, n2, n3, n4);
            }
        }
    }
    
    private static class DelegatingPainter extends SynthPainter
    {
        private static SynthPainter getPainter(SynthContext synthContext, String s, int n) {
            return ParsedSynthStyle.access$200((ParsedSynthStyle)synthContext.getStyle(), synthContext, s, n);
        }
        
        @Override
        public void paintArrowButtonBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "arrowbuttonbackground", -1).paintArrowButtonBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintArrowButtonBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "arrowbuttonborder", -1).paintArrowButtonBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintArrowButtonForeground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            getPainter(synthContext, "arrowbuttonforeground", n5).paintArrowButtonForeground(synthContext, graphics, n, n2, n3, n4, n5);
        }
        
        @Override
        public void paintButtonBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "buttonbackground", -1).paintButtonBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintButtonBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "buttonborder", -1).paintButtonBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintCheckBoxMenuItemBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "checkboxmenuitembackground", -1).paintCheckBoxMenuItemBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintCheckBoxMenuItemBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "checkboxmenuitemborder", -1).paintCheckBoxMenuItemBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintCheckBoxBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "checkboxbackground", -1).paintCheckBoxBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintCheckBoxBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "checkboxborder", -1).paintCheckBoxBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintColorChooserBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "colorchooserbackground", -1).paintColorChooserBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintColorChooserBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "colorchooserborder", -1).paintColorChooserBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintComboBoxBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "comboboxbackground", -1).paintComboBoxBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintComboBoxBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "comboboxborder", -1).paintComboBoxBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintDesktopIconBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "desktopiconbackground", -1).paintDesktopIconBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintDesktopIconBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "desktopiconborder", -1).paintDesktopIconBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintDesktopPaneBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "desktoppanebackground", -1).paintDesktopPaneBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintDesktopPaneBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "desktoppaneborder", -1).paintDesktopPaneBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintEditorPaneBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "editorpanebackground", -1).paintEditorPaneBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintEditorPaneBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "editorpaneborder", -1).paintEditorPaneBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintFileChooserBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "filechooserbackground", -1).paintFileChooserBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintFileChooserBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "filechooserborder", -1).paintFileChooserBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintFormattedTextFieldBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "formattedtextfieldbackground", -1).paintFormattedTextFieldBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintFormattedTextFieldBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "formattedtextfieldborder", -1).paintFormattedTextFieldBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintInternalFrameTitlePaneBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "internalframetitlepanebackground", -1).paintInternalFrameTitlePaneBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintInternalFrameTitlePaneBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "internalframetitlepaneborder", -1).paintInternalFrameTitlePaneBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintInternalFrameBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "internalframebackground", -1).paintInternalFrameBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintInternalFrameBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "internalframeborder", -1).paintInternalFrameBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintLabelBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "labelbackground", -1).paintLabelBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintLabelBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "labelborder", -1).paintLabelBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintListBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "listbackground", -1).paintListBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintListBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "listborder", -1).paintListBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintMenuBarBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "menubarbackground", -1).paintMenuBarBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintMenuBarBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "menubarborder", -1).paintMenuBarBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintMenuItemBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "menuitembackground", -1).paintMenuItemBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintMenuItemBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "menuitemborder", -1).paintMenuItemBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintMenuBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "menubackground", -1).paintMenuBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintMenuBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "menuborder", -1).paintMenuBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintOptionPaneBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "optionpanebackground", -1).paintOptionPaneBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintOptionPaneBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "optionpaneborder", -1).paintOptionPaneBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintPanelBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "panelbackground", -1).paintPanelBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintPanelBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "panelborder", -1).paintPanelBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintPasswordFieldBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "passwordfieldbackground", -1).paintPasswordFieldBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintPasswordFieldBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "passwordfieldborder", -1).paintPasswordFieldBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintPopupMenuBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "popupmenubackground", -1).paintPopupMenuBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintPopupMenuBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "popupmenuborder", -1).paintPopupMenuBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintProgressBarBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "progressbarbackground", -1).paintProgressBarBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintProgressBarBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            getPainter(synthContext, "progressbarbackground", n5).paintProgressBarBackground(synthContext, graphics, n, n2, n3, n4, n5);
        }
        
        @Override
        public void paintProgressBarBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "progressbarborder", -1).paintProgressBarBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintProgressBarBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            getPainter(synthContext, "progressbarborder", n5).paintProgressBarBorder(synthContext, graphics, n, n2, n3, n4, n5);
        }
        
        @Override
        public void paintProgressBarForeground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            getPainter(synthContext, "progressbarforeground", n5).paintProgressBarForeground(synthContext, graphics, n, n2, n3, n4, n5);
        }
        
        @Override
        public void paintRadioButtonMenuItemBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "radiobuttonmenuitembackground", -1).paintRadioButtonMenuItemBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintRadioButtonMenuItemBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "radiobuttonmenuitemborder", -1).paintRadioButtonMenuItemBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintRadioButtonBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "radiobuttonbackground", -1).paintRadioButtonBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintRadioButtonBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "radiobuttonborder", -1).paintRadioButtonBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintRootPaneBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "rootpanebackground", -1).paintRootPaneBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintRootPaneBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "rootpaneborder", -1).paintRootPaneBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintScrollBarBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "scrollbarbackground", -1).paintScrollBarBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintScrollBarBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            getPainter(synthContext, "scrollbarbackground", n5).paintScrollBarBackground(synthContext, graphics, n, n2, n3, n4, n5);
        }
        
        @Override
        public void paintScrollBarBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "scrollbarborder", -1).paintScrollBarBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintScrollBarBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            getPainter(synthContext, "scrollbarborder", n5).paintScrollBarBorder(synthContext, graphics, n, n2, n3, n4, n5);
        }
        
        @Override
        public void paintScrollBarThumbBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            getPainter(synthContext, "scrollbarthumbbackground", n5).paintScrollBarThumbBackground(synthContext, graphics, n, n2, n3, n4, n5);
        }
        
        @Override
        public void paintScrollBarThumbBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            getPainter(synthContext, "scrollbarthumbborder", n5).paintScrollBarThumbBorder(synthContext, graphics, n, n2, n3, n4, n5);
        }
        
        @Override
        public void paintScrollBarTrackBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "scrollbartrackbackground", -1).paintScrollBarTrackBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintScrollBarTrackBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            getPainter(synthContext, "scrollbartrackbackground", n5).paintScrollBarTrackBackground(synthContext, graphics, n, n2, n3, n4, n5);
        }
        
        @Override
        public void paintScrollBarTrackBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "scrollbartrackborder", -1).paintScrollBarTrackBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintScrollBarTrackBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            getPainter(synthContext, "scrollbartrackborder", n5).paintScrollBarTrackBorder(synthContext, graphics, n, n2, n3, n4, n5);
        }
        
        @Override
        public void paintScrollPaneBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "scrollpanebackground", -1).paintScrollPaneBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintScrollPaneBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "scrollpaneborder", -1).paintScrollPaneBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintSeparatorBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "separatorbackground", -1).paintSeparatorBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintSeparatorBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            getPainter(synthContext, "separatorbackground", n5).paintSeparatorBackground(synthContext, graphics, n, n2, n3, n4, n5);
        }
        
        @Override
        public void paintSeparatorBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "separatorborder", -1).paintSeparatorBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintSeparatorBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            getPainter(synthContext, "separatorborder", n5).paintSeparatorBorder(synthContext, graphics, n, n2, n3, n4, n5);
        }
        
        @Override
        public void paintSeparatorForeground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            getPainter(synthContext, "separatorforeground", n5).paintSeparatorForeground(synthContext, graphics, n, n2, n3, n4, n5);
        }
        
        @Override
        public void paintSliderBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "sliderbackground", -1).paintSliderBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintSliderBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            getPainter(synthContext, "sliderbackground", n5).paintSliderBackground(synthContext, graphics, n, n2, n3, n4, n5);
        }
        
        @Override
        public void paintSliderBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "sliderborder", -1).paintSliderBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintSliderBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            getPainter(synthContext, "sliderborder", n5).paintSliderBorder(synthContext, graphics, n, n2, n3, n4, n5);
        }
        
        @Override
        public void paintSliderThumbBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            getPainter(synthContext, "sliderthumbbackground", n5).paintSliderThumbBackground(synthContext, graphics, n, n2, n3, n4, n5);
        }
        
        @Override
        public void paintSliderThumbBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            getPainter(synthContext, "sliderthumbborder", n5).paintSliderThumbBorder(synthContext, graphics, n, n2, n3, n4, n5);
        }
        
        @Override
        public void paintSliderTrackBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "slidertrackbackground", -1).paintSliderTrackBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintSliderTrackBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            getPainter(synthContext, "slidertrackbackground", n5).paintSliderTrackBackground(synthContext, graphics, n, n2, n3, n4, n5);
        }
        
        @Override
        public void paintSliderTrackBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "slidertrackborder", -1).paintSliderTrackBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintSliderTrackBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            getPainter(synthContext, "slidertrackborder", n5).paintSliderTrackBorder(synthContext, graphics, n, n2, n3, n4, n5);
        }
        
        @Override
        public void paintSpinnerBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "spinnerbackground", -1).paintSpinnerBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintSpinnerBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "spinnerborder", -1).paintSpinnerBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintSplitPaneDividerBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "splitpanedividerbackground", -1).paintSplitPaneDividerBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintSplitPaneDividerBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            getPainter(synthContext, "splitpanedividerbackground", n5).paintSplitPaneDividerBackground(synthContext, graphics, n, n2, n3, n4, n5);
        }
        
        @Override
        public void paintSplitPaneDividerForeground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            getPainter(synthContext, "splitpanedividerforeground", n5).paintSplitPaneDividerForeground(synthContext, graphics, n, n2, n3, n4, n5);
        }
        
        @Override
        public void paintSplitPaneDragDivider(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            getPainter(synthContext, "splitpanedragdivider", n5).paintSplitPaneDragDivider(synthContext, graphics, n, n2, n3, n4, n5);
        }
        
        @Override
        public void paintSplitPaneBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "splitpanebackground", -1).paintSplitPaneBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintSplitPaneBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "splitpaneborder", -1).paintSplitPaneBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintTabbedPaneBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "tabbedpanebackground", -1).paintTabbedPaneBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintTabbedPaneBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "tabbedpaneborder", -1).paintTabbedPaneBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintTabbedPaneTabAreaBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "tabbedpanetabareabackground", -1).paintTabbedPaneTabAreaBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintTabbedPaneTabAreaBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            getPainter(synthContext, "tabbedpanetabareabackground", n5).paintTabbedPaneTabAreaBackground(synthContext, graphics, n, n2, n3, n4, n5);
        }
        
        @Override
        public void paintTabbedPaneTabAreaBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "tabbedpanetabareaborder", -1).paintTabbedPaneTabAreaBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintTabbedPaneTabAreaBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            getPainter(synthContext, "tabbedpanetabareaborder", n5).paintTabbedPaneTabAreaBorder(synthContext, graphics, n, n2, n3, n4, n5);
        }
        
        @Override
        public void paintTabbedPaneTabBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            getPainter(synthContext, "tabbedpanetabbackground", -1).paintTabbedPaneTabBackground(synthContext, graphics, n, n2, n3, n4, n5);
        }
        
        @Override
        public void paintTabbedPaneTabBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5, int n6) {
            getPainter(synthContext, "tabbedpanetabbackground", n6).paintTabbedPaneTabBackground(synthContext, graphics, n, n2, n3, n4, n5, n6);
        }
        
        @Override
        public void paintTabbedPaneTabBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            getPainter(synthContext, "tabbedpanetabborder", -1).paintTabbedPaneTabBorder(synthContext, graphics, n, n2, n3, n4, n5);
        }
        
        @Override
        public void paintTabbedPaneTabBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5, int n6) {
            getPainter(synthContext, "tabbedpanetabborder", n6).paintTabbedPaneTabBorder(synthContext, graphics, n, n2, n3, n4, n5, n6);
        }
        
        @Override
        public void paintTabbedPaneContentBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "tabbedpanecontentbackground", -1).paintTabbedPaneContentBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintTabbedPaneContentBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "tabbedpanecontentborder", -1).paintTabbedPaneContentBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintTableHeaderBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "tableheaderbackground", -1).paintTableHeaderBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintTableHeaderBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "tableheaderborder", -1).paintTableHeaderBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintTableBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "tablebackground", -1).paintTableBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintTableBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "tableborder", -1).paintTableBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintTextAreaBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "textareabackground", -1).paintTextAreaBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintTextAreaBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "textareaborder", -1).paintTextAreaBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintTextPaneBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "textpanebackground", -1).paintTextPaneBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintTextPaneBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "textpaneborder", -1).paintTextPaneBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintTextFieldBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "textfieldbackground", -1).paintTextFieldBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintTextFieldBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "textfieldborder", -1).paintTextFieldBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintToggleButtonBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "togglebuttonbackground", -1).paintToggleButtonBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintToggleButtonBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "togglebuttonborder", -1).paintToggleButtonBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintToolBarBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "toolbarbackground", -1).paintToolBarBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintToolBarBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            getPainter(synthContext, "toolbarbackground", n5).paintToolBarBackground(synthContext, graphics, n, n2, n3, n4, n5);
        }
        
        @Override
        public void paintToolBarBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "toolbarborder", -1).paintToolBarBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintToolBarBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            getPainter(synthContext, "toolbarborder", n5).paintToolBarBorder(synthContext, graphics, n, n2, n3, n4, n5);
        }
        
        @Override
        public void paintToolBarContentBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "toolbarcontentbackground", -1).paintToolBarContentBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintToolBarContentBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            getPainter(synthContext, "toolbarcontentbackground", n5).paintToolBarContentBackground(synthContext, graphics, n, n2, n3, n4, n5);
        }
        
        @Override
        public void paintToolBarContentBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "toolbarcontentborder", -1).paintToolBarContentBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintToolBarContentBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            getPainter(synthContext, "toolbarcontentborder", n5).paintToolBarContentBorder(synthContext, graphics, n, n2, n3, n4, n5);
        }
        
        @Override
        public void paintToolBarDragWindowBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "toolbardragwindowbackground", -1).paintToolBarDragWindowBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintToolBarDragWindowBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            getPainter(synthContext, "toolbardragwindowbackground", n5).paintToolBarDragWindowBackground(synthContext, graphics, n, n2, n3, n4, n5);
        }
        
        @Override
        public void paintToolBarDragWindowBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "toolbardragwindowborder", -1).paintToolBarDragWindowBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintToolBarDragWindowBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
            getPainter(synthContext, "toolbardragwindowborder", n5).paintToolBarDragWindowBorder(synthContext, graphics, n, n2, n3, n4, n5);
        }
        
        @Override
        public void paintToolTipBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "tooltipbackground", -1).paintToolTipBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintToolTipBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "tooltipborder", -1).paintToolTipBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintTreeBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "treebackground", -1).paintTreeBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintTreeBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "treeborder", -1).paintTreeBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintTreeCellBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "treecellbackground", -1).paintTreeCellBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintTreeCellBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "treecellborder", -1).paintTreeCellBorder(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintTreeCellFocus(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "treecellfocus", -1).paintTreeCellFocus(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintViewportBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "viewportbackground", -1).paintViewportBackground(synthContext, graphics, n, n2, n3, n4);
        }
        
        @Override
        public void paintViewportBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
            getPainter(synthContext, "viewportborder", -1).paintViewportBorder(synthContext, graphics, n, n2, n3, n4);
        }
    }
}
